==> gtoonz-0.4.2.tar.gz: gtoonz-0.4.2/src/gui.c <==
#include <config.h>

#include <stdio.h>
#include <time.h>
#include <gnome.h>
#include <libgnomevfs/gnome-vfs.h>
#include <gconf/gconf-client.h>

#include "gtoonz.h"

static GtkWidget *statusbar;
void
status_update (const char *message)
{
	gnome_appbar_pop (GNOME_APPBAR (statusbar));
	gnome_appbar_push (GNOME_APPBAR (statusbar), message);
	
	return;
}

static void
clear (Cartoon *cartoon)
{
	Item *item;
	GSList *list = cartoon->item_list;
	
	while (list) {
		item = list->data;
		/* Item free */
		if (item->handle) {
			gnome_vfs_async_cancel (item->handle);
		}
		g_free (item->url);
		g_free (item->buf);
		gtk_container_remove (GTK_CONTAINER(cartoon->images_box),
				      item->event);
		gdk_pixbuf_loader_close (item->loader, NULL);
		g_object_unref (G_OBJECT(item->loader));
		g_free (item);
		list = list->next;
	}
	g_slist_free (cartoon->item_list);
	cartoon->item_list = NULL;
	
	return;
}

static void
view (Cartoon *cartoon)
{
	int day, month, year;
	
	/* ȭ   ߴٸ ħ */
	if (cartoon->info == NULL) {
		status_update (_("Select a cartoon"));
		return;
	}

	/*  ȭ Ͱ ִٸ  */
	if (cartoon->item_list != NULL) {
		clear (cartoon);
	}

	gtk_calendar_get_date (GTK_CALENDAR(cartoon->calendar),
			       &year, &month, &day);
	month += 1;
	cartoon->info->make_url (cartoon, year, month, day);
	download (cartoon);

	return;
}

static void
calendar_update (Cartoon *cartoon, int i)
{
	int day, month, year;
	struct tm tm;
	time_t t;

	gtk_calendar_get_date (GTK_CALENDAR(cartoon->calendar),
			       &year, &month, &day);

	memset(&tm, 0, sizeof(tm));
	tm.tm_year = year - 1900;
	tm.tm_mon = month;
	tm.tm_mday = day + i;
	t = mktime (&tm);
	localtime_r (&t, &tm);
	
	gtk_calendar_select_month (GTK_CALENDAR(cartoon->calendar),
				   tm.tm_mon,
				   tm.tm_year + 1900);
	gtk_calendar_select_day (GTK_CALENDAR(cartoon->calendar),
				 tm.tm_mday);
	
	return;
}

static void
destroy_cb (GtkObject *object,
	    gpointer user_data)
{
	g_free (user_data);
	gtk_main_quit ();
}

static void
calendar_update_cb (GtkCalendar *calendar,
		    gpointer user_data)
{
	view ((Cartoon *)user_data);

	return;
}

static void
back_button_cb (GtkButton *button,
		gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;

	calendar_update (cartoon, -1);
	view (cartoon);

	return;
}

static void
forward_button_cb (GtkButton *button,
		   gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;

	calendar_update (cartoon, 1);
	view (cartoon);
	
	return;
}

static void
today_button_cb (GtkWidget *button,
		 gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *) user_data;
	struct tm *foo;
	time_t t;

	t = time (NULL);
	foo = localtime (&t);
	gtk_calendar_select_month (GTK_CALENDAR(cartoon->calendar),
				   foo->tm_mon,
				   foo->tm_year + 1900);
	gtk_calendar_select_day (GTK_CALENDAR(cartoon->calendar),
				 foo->tm_mday);
	view (cartoon);

	return;
}

static void
pref_check_button_cb (GtkToggleButton *button,
		      gpointer user_data)
{
	CartoonInfo *info = (CartoonInfo *)user_data;
	GConfClient *client;
	gboolean bool;
	gchar *key;

	client = g_object_get_data (G_OBJECT (button), "client");
	bool = gtk_toggle_button_get_active (button);
	key = g_strdup_printf ("%s%s", "/apps/gtoonz/", info->label);
	
	gconf_client_set_bool (client, key, !bool, NULL);
	
	g_free (key);
}
static void
preferences_button_cb (GtkButton *widget,
		       gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;
	GtkWidget *dialog;
	GtkWidget *frame;
	GtkWidget *vbox;
	GtkWidget *button;
	gchar *key;
	gboolean bool;
	int i;
	
	frame = gtk_frame_new (_("Select cartoons"));
	vbox = gtk_vbox_new (FALSE, 1);
	gtk_container_add (GTK_CONTAINER (frame), vbox);

	for (i = 0; i < N_CARTOONS; i++) {
		button = gtk_check_button_new_with_label (CartoonInfoList[i].label);
		g_object_set_data (G_OBJECT (button), "client", cartoon->client);
		key = g_strdup_printf ("%s%s", "/apps/gtoonz/", CartoonInfoList[i].label);
		bool = gconf_client_get_bool (cartoon->client, key, NULL);
		g_free (key);

		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), !bool);

		g_signal_connect (G_OBJECT (button), "toggled",
				  G_CALLBACK (pref_check_button_cb),
				  &CartoonInfoList[i]);
		gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
	}
	
	dialog = gtk_dialog_new_with_buttons (_("Preferences"),
					      GTK_WINDOW (cartoon->app),
					      GTK_DIALOG_DESTROY_WITH_PARENT,
					      GTK_STOCK_OK,
					      GTK_RESPONSE_NONE,
					      NULL);
	g_signal_connect_swapped (G_OBJECT (dialog),
				  "response",
				  G_CALLBACK (gtk_widget_destroy),
				  G_OBJECT (dialog));
	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), frame);
	
	gtk_widget_show_all (dialog);
}

static void
about_cb (GtkButton *button,
	  gpointer user_data)
{
	static GtkWidget *about = NULL;
	const char *authors[] = {
		("ddt <ddt@mirstyle.org>"),
		NULL,
	};
	const char *translator_credits = _("translator_credits");

	if (about) {
		gdk_window_raise (about->window);
		return;
	}

	about = gnome_about_new (PACKAGE, VERSION,
				 "Copyright 2002 ddt",
				 _("Newspaper cartoons viewer"),
				 (const gchar **) authors,
				 NULL,
				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
				 NULL);
	g_signal_connect (G_OBJECT (about), "destroy",
			  G_CALLBACK (gtk_widget_destroy), NULL);
	gtk_widget_show (about);
	return;
}

static void
cartoon_button_cb (GtkButton *button,
		   gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;
	Cartoon_t *type;

	type = g_object_get_data (G_OBJECT (button), "type");
	cartoon->info = &CartoonInfoList[GPOINTER_TO_INT (type)];
	view (cartoon);
	
	return;
}

static void
key_changed_cb (GConfClient *client,
		guint cnxn_id,
		GConfEntry *entry,
		gpointer data)
{
	GtkWidget *button = (GtkWidget *)data;
	gboolean bool;

	bool = gconf_value_get_bool (gconf_entry_get_value (entry));
	if (bool == TRUE) {
		gtk_widget_hide (button);
	} else {
		gtk_widget_show (button);
	}
}
static void
cartoon_button_init (Cartoon *cartoon, GtkWidget *button_box)
{
	CartoonInfo *info;
	GtkWidget *radio = NULL;
	gboolean bool;
	gchar *key;
	int i;

	for (i = 0; i <N_CARTOONS; i++) {
		info = &CartoonInfoList[i];
		key = g_strdup_printf ("%s%s", "/apps/gtoonz/", info->label);
		bool = gconf_client_get_bool (cartoon->client, key, NULL);
		
		if (radio == NULL) {
			radio = gtk_radio_button_new_with_label (NULL, info->label);
		} else {
			radio = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio), info->label);
		}
		g_object_set_data (G_OBJECT (radio), "type",
				   GINT_TO_POINTER (info->cartoon_t));
		g_signal_connect (G_OBJECT (radio), "clicked",
				  G_CALLBACK (cartoon_button_cb), cartoon);
		gtk_box_pack_start (GTK_BOX (button_box), radio, FALSE, FALSE, 0);

		gconf_client_notify_add (cartoon->client, key,
					 key_changed_cb,
					 radio, NULL, NULL);
		if (bool == TRUE) {
			gtk_widget_hide (radio);
		} else {
			gtk_widget_show (radio);
		}
		g_free (key);
	}
	return;
}

GnomeUIInfo toolbar[] = {
	GNOMEUIINFO_ITEM_STOCK (N_("Previous"),
				N_("Go to the previous cartoon"),
				back_button_cb, GTK_STOCK_GO_BACK),
	GNOMEUIINFO_ITEM_STOCK (N_("Next"),
				N_("Go to the next cartoon"),
				forward_button_cb, GTK_STOCK_GO_FORWARD),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (N_("Today"),
				N_("Show today's cartoon"),
				today_button_cb, GTK_STOCK_JUMP_TO),
	GNOMEUIINFO_ITEM_STOCK (N_("Preferences"),
				N_("Preferences"),
				preferences_button_cb, GTK_STOCK_PREFERENCES),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (N_("Exit"),
				N_("Quit the gtoonz"),
				destroy_cb, GTK_STOCK_QUIT),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (N_("About"),
				N_("About the gtoonz"),
				about_cb, GNOME_STOCK_ABOUT),
	GNOMEUIINFO_END,
};

void
gui_init (Cartoon *cartoon)
{
	GtkWidget *vbox1;
	GtkWidget *handlebox;
	GtkWidget *hbox1;
	GtkWidget *scrw;
	GtkWidget *vbox2;
	GtkWidget *frame;
	GtkWidget *scrw2;
	GtkWidget *vbutton_box;

	cartoon->app = gnome_app_new (PACKAGE, PACKAGE);
	gtk_window_set_title (GTK_WINDOW (cartoon->app), PACKAGE_STRING);
	gtk_window_resize (GTK_WINDOW(cartoon->app), 700, 500);
	g_signal_connect (G_OBJECT(cartoon->app), "destroy",
			  G_CALLBACK(destroy_cb), (gpointer)cartoon);

	gnome_app_create_toolbar_with_data (GNOME_APP (cartoon->app),
					    toolbar, (gpointer) cartoon);
	statusbar = gnome_appbar_new (FALSE, TRUE,
				      GNOME_PREFERENCES_USER);
	gnome_app_set_statusbar (GNOME_APP (cartoon->app), statusbar);

	vbox1 = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (vbox1);
	gnome_app_set_contents (GNOME_APP (cartoon->app), vbox1);
	
	hbox1 = gtk_hbox_new (FALSE, 0);
	gtk_widget_show (hbox1);
	gtk_box_pack_start (GTK_BOX(vbox1), hbox1, TRUE, TRUE, 0);

	scrw = gtk_scrolled_window_new (NULL, NULL);
	gtk_widget_show (scrw);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrw),
					GTK_POLICY_AUTOMATIC,
					GTK_POLICY_AUTOMATIC);
	gtk_box_pack_start (GTK_BOX(hbox1), scrw, TRUE, TRUE, 0);

	cartoon->images_box = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (cartoon->images_box);
	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(scrw),
					       cartoon->images_box);

	vbox2 = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (vbox2);
	gtk_box_pack_end (GTK_BOX(hbox1), vbox2, FALSE, FALSE, 1);

	cartoon->calendar = gtk_calendar_new ();
	gtk_widget_show (cartoon->calendar);
	g_signal_connect (G_OBJECT (cartoon->calendar),
			  "day-selected-double-click",
			  G_CALLBACK (calendar_update_cb), (gpointer) cartoon);
	gtk_box_pack_start (GTK_BOX (vbox2), cartoon->calendar, FALSE, FALSE, 0);

	frame = gtk_frame_new (_("Cartoons"));
	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
	gtk_widget_show (frame);
	gtk_box_pack_start (GTK_BOX (vbox2), frame, TRUE, TRUE, 3);

	scrw2 = gtk_scrolled_window_new (NULL, NULL);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrw2),
					GTK_POLICY_AUTOMATIC,
					GTK_POLICY_AUTOMATIC);
	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrw2),
					     GTK_SHADOW_NONE);
	gtk_widget_show (scrw2);
	gtk_container_add (GTK_CONTAINER (frame), scrw2);
	
	vbutton_box = gtk_vbutton_box_new ();
	gtk_button_box_set_layout (GTK_BUTTON_BOX (vbutton_box),
				   GTK_BUTTONBOX_START);
	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(scrw2),
					       vbutton_box);
	gtk_widget_show (vbutton_box);
	cartoon_button_init (cartoon, vbutton_box);
	
	gtk_widget_show (cartoon->app);
	return;
}

==> gtoonz-0.4.4.tar.gz: gtoonz-0.4.4/src/gui.c <==
#include <config.h>

#include <stdio.h>
#include <time.h>
#include <gnome.h>
#include <libgnomevfs/gnome-vfs.h>
#include <gconf/gconf-client.h>

#include "gtoonz.h"

static GtkWidget *statusbar;
void
status_update (const char *message)
{
	gnome_appbar_pop (GNOME_APPBAR (statusbar));
	gnome_appbar_push (GNOME_APPBAR (statusbar), message);
	
	return;
}

static void
clear (Cartoon *cartoon)
{
	Item *item;
	GSList *list = cartoon->item_list;

	while (list) {
		item = list->data;
		/* Item free */
		if (item->handle) {
			gnome_vfs_async_cancel (item->handle);
		}
		g_free (item->url);
		g_free (item->buf);
		gtk_container_remove (GTK_CONTAINER(cartoon->images_box),
				      item->event);
		gdk_pixbuf_loader_close (item->loader, NULL);
		g_object_unref (G_OBJECT(item->loader));
		g_free (item);
		list = list->next;
	}
	g_slist_free (cartoon->item_list);
	cartoon->item_list = NULL;

	return;
}

static void
view (Cartoon *cartoon)
{
	int day, month, year;
	
	/* ȭ   ߴٸ ħ */
	if (cartoon->info == NULL) {
		status_update (_("Select a cartoon"));
		return;
	}

	/*  ȭ Ͱ ִٸ  */
	if (cartoon->item_list != NULL) {
		clear (cartoon);
	}

	gtk_calendar_get_date (GTK_CALENDAR(cartoon->calendar),
			       &year, &month, &day);
	month += 1;
	cartoon->info->make_url (cartoon, year, month, day);
	download (cartoon);

	return;
}

static void
calendar_update (Cartoon *cartoon, int i)
{
	int day, month, year;
	struct tm tm;
	time_t t;

	gtk_calendar_get_date (GTK_CALENDAR(cartoon->calendar),
			       &year, &month, &day);

	memset(&tm, 0, sizeof(tm));
	tm.tm_year = year - 1900;
	tm.tm_mon = month;
	tm.tm_mday = day + i;
	t = mktime (&tm);
	localtime_r (&t, &tm);
	
	gtk_calendar_select_month (GTK_CALENDAR(cartoon->calendar),
				   tm.tm_mon,
				   tm.tm_year + 1900);
	gtk_calendar_select_day (GTK_CALENDAR(cartoon->calendar),
				 tm.tm_mday);
	
	return;
}

static void
destroy_cb (GtkObject *object,
	    gpointer user_data)
{
	g_free (user_data);
	gtk_main_quit ();
}

static void
calendar_update_cb (GtkCalendar *calendar,
		    gpointer user_data)
{
	view ((Cartoon *)user_data);

	return;
}

static void
back_button_cb (GtkButton *button,
		gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;

	calendar_update (cartoon, -1);
	view (cartoon);

	return;
}

static void
forward_button_cb (GtkButton *button,
		   gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;

	calendar_update (cartoon, 1);
	view (cartoon);
	
	return;
}

static void
today_button_cb (GtkWidget *button,
		 gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *) user_data;
	struct tm *foo;
	time_t t;

	t = time (NULL);
	foo = localtime (&t);
	gtk_calendar_select_month (GTK_CALENDAR(cartoon->calendar),
				   foo->tm_mon,
				   foo->tm_year + 1900);
	gtk_calendar_select_day (GTK_CALENDAR(cartoon->calendar),
				 foo->tm_mday);
	view (cartoon);

	return;
}

static void
pref_check_button_cb (GtkToggleButton *button,
		      gpointer user_data)
{
	CartoonInfo *info = (CartoonInfo *)user_data;
	GConfClient *client;
	gboolean bool;
	gchar *key;

	client = g_object_get_data (G_OBJECT (button), "client");
	bool = gtk_toggle_button_get_active (button);
	key = g_strdup_printf ("%s%s", "/apps/gtoonz/", info->label);
	
	gconf_client_set_bool (client, key, !bool, NULL);
	
	g_free (key);
}
static void
preferences_button_cb (GtkButton *widget,
		       gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;
	GtkWidget *dialog;
	GtkWidget *frame;
	GtkWidget *vbox;
	GtkWidget *button;
	gchar *key;
	gboolean bool;
	int i;
	
	frame = gtk_frame_new (_("Select cartoons"));
	vbox = gtk_vbox_new (FALSE, 1);
	gtk_container_add (GTK_CONTAINER (frame), vbox);

	for (i = 0; i < N_CARTOONS; i++) {
		button = gtk_check_button_new_with_label (CartoonInfoList[i].label);
		g_object_set_data (G_OBJECT (button), "client", cartoon->client);
		key = g_strdup_printf ("%s%s", "/apps/gtoonz/", CartoonInfoList[i].label);
		bool = gconf_client_get_bool (cartoon->client, key, NULL);
		g_free (key);

		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), !bool);

		g_signal_connect (G_OBJECT (button), "toggled",
				  G_CALLBACK (pref_check_button_cb),
				  &CartoonInfoList[i]);
		gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
	}
	
	dialog = gtk_dialog_new_with_buttons (_("Preferences"),
					      GTK_WINDOW (cartoon->app),
					      GTK_DIALOG_DESTROY_WITH_PARENT,
					      GTK_STOCK_OK,
					      GTK_RESPONSE_NONE,
					      NULL);
	g_signal_connect_swapped (G_OBJECT (dialog),
				  "response",
				  G_CALLBACK (gtk_widget_destroy),
				  G_OBJECT (dialog));
	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), frame);
	
	gtk_widget_show_all (dialog);
}

static void
about_cb (GtkButton *button,
	  gpointer user_data)
{
	static GtkWidget *about = NULL;
	const char *authors[] = {
		("ddt <ddt@mirstyle.org>"),
		NULL,
	};
	const char *translator_credits = _("translator_credits");

	if (about) {
		gdk_window_raise (about->window);
		return;
	}

	about = gnome_about_new (PACKAGE, VERSION,
				 "Copyright 2002 ddt",
				 _("Newspaper cartoons viewer"),
				 (const gchar **) authors,
				 NULL,
				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
				 NULL);
	g_signal_connect (G_OBJECT (about), "destroy",
			  G_CALLBACK (gtk_widget_destroyed), &about);
	gtk_widget_show (about);
	return;
}

static void
cartoon_button_cb (GtkButton *button,
		   gpointer user_data)
{
	Cartoon *cartoon = (Cartoon *)user_data;
	Cartoon_t *type;

	type = g_object_get_data (G_OBJECT (button), "type");
	cartoon->info = &CartoonInfoList[GPOINTER_TO_INT (type)];
	view (cartoon);
	
	return;
}

static void
key_changed_cb (GConfClient *client,
		guint cnxn_id,
		GConfEntry *entry,
		gpointer data)
{
	GtkWidget *button = (GtkWidget *)data;
	gboolean bool;

	bool = gconf_value_get_bool (gconf_entry_get_value (entry));
	if (bool == TRUE) {
		gtk_widget_hide (button);
	} else {
		gtk_widget_show (button);
	}
}
static void
cartoon_button_init (Cartoon *cartoon, GtkWidget *button_box)
{
	CartoonInfo *info;
	GtkWidget *radio = NULL;
	gboolean bool;
	gchar *key;
	int i;

	for (i = 0; i <N_CARTOONS; i++) {
		info = &CartoonInfoList[i];
		key = g_strdup_printf ("%s%s", "/apps/gtoonz/", info->label);
		bool = gconf_client_get_bool (cartoon->client, key, NULL);
		
		if (radio == NULL) {
			radio = gtk_radio_button_new_with_label (NULL, info->label);
		} else {
			radio = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio), info->label);
		}
		gtk_button_set_relief (GTK_BUTTON (radio), GTK_RELIEF_NONE);
		gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radio), FALSE);
		g_object_set_data (G_OBJECT (radio), "type",
				   GINT_TO_POINTER (info->cartoon_t));
		g_signal_connect (G_OBJECT (radio), "clicked",
				  G_CALLBACK (cartoon_button_cb), cartoon);
		gtk_box_pack_start (GTK_BOX (button_box), radio, FALSE, FALSE, 0);

		gconf_client_notify_add (cartoon->client, key,
					 key_changed_cb,
					 radio, NULL, NULL);
		if (bool == TRUE) {
			gtk_widget_hide (radio);
		} else {
			gtk_widget_show (radio);
		}
		g_free (key);
	}
	return;
}

GnomeUIInfo toolbar[] = {
	GNOMEUIINFO_ITEM_STOCK (N_("Previous"),
				N_("Go to the previous cartoon"),
				back_button_cb, GTK_STOCK_GO_BACK),
	GNOMEUIINFO_ITEM_STOCK (N_("Next"),
				N_("Go to the next cartoon"),
				forward_button_cb, GTK_STOCK_GO_FORWARD),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (N_("Today"),
				N_("Show today's cartoon"),
				today_button_cb, GTK_STOCK_JUMP_TO),
	GNOMEUIINFO_ITEM_STOCK (N_("Preferences"),
				N_("Preferences"),
				preferences_button_cb, GTK_STOCK_PREFERENCES),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (N_("Exit"),
				N_("Quit the gtoonz"),
				destroy_cb, GTK_STOCK_QUIT),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (N_("About"),
				N_("About the gtoonz"),
				about_cb, GNOME_STOCK_ABOUT),
	GNOMEUIINFO_END,
};

void
gui_init (Cartoon *cartoon)
{
	GtkWidget *vbox1;
	GtkWidget *handlebox;
	GtkWidget *hbox1;
	GtkWidget *scrw;
	GtkWidget *vbox2;
	GtkWidget *frame;
	GtkWidget *scrw2;
	GtkWidget *vbutton_box;

	cartoon->app = gnome_app_new (PACKAGE, PACKAGE);
	gtk_window_set_title (GTK_WINDOW (cartoon->app), PACKAGE_STRING);
	gtk_window_resize (GTK_WINDOW(cartoon->app), 700, 500);
	g_signal_connect (G_OBJECT(cartoon->app), "destroy",
			  G_CALLBACK(destroy_cb), (gpointer)cartoon);

	gnome_app_create_toolbar_with_data (GNOME_APP (cartoon->app),
					    toolbar, (gpointer) cartoon);
	statusbar = gnome_appbar_new (FALSE, TRUE,
				      GNOME_PREFERENCES_USER);
	gnome_app_set_statusbar (GNOME_APP (cartoon->app), statusbar);

	vbox1 = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (vbox1);
	gnome_app_set_contents (GNOME_APP (cartoon->app), vbox1);
	
	hbox1 = gtk_hbox_new (FALSE, 0);
	gtk_widget_show (hbox1);
	gtk_box_pack_start (GTK_BOX(vbox1), hbox1, TRUE, TRUE, 0);

	scrw = gtk_scrolled_window_new (NULL, NULL);
	gtk_widget_show (scrw);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrw),
					GTK_POLICY_AUTOMATIC,
					GTK_POLICY_AUTOMATIC);
	gtk_box_pack_start (GTK_BOX(hbox1), scrw, TRUE, TRUE, 0);

	cartoon->images_box = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (cartoon->images_box);
	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(scrw),
					       cartoon->images_box);

	vbox2 = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (vbox2);
	gtk_box_pack_end (GTK_BOX(hbox1), vbox2, FALSE, FALSE, 1);

	cartoon->calendar = gtk_calendar_new ();
	gtk_widget_show (cartoon->calendar);
	g_signal_connect (G_OBJECT (cartoon->calendar),
			  "day-selected-double-click",
			  G_CALLBACK (calendar_update_cb), (gpointer) cartoon);
	gtk_box_pack_start (GTK_BOX (vbox2), cartoon->calendar, FALSE, FALSE, 0);

	frame = gtk_frame_new (_("Cartoons"));
	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
	gtk_widget_show (frame);
	gtk_box_pack_start (GTK_BOX (vbox2), frame, TRUE, TRUE, 3);

	scrw2 = gtk_scrolled_window_new (NULL, NULL);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrw2),
					GTK_POLICY_AUTOMATIC,
					GTK_POLICY_AUTOMATIC);
	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrw2),
					     GTK_SHADOW_NONE);
	gtk_widget_show (scrw2);
	gtk_container_add (GTK_CONTAINER (frame), scrw2);
	
	vbutton_box = gtk_vbutton_box_new ();
	gtk_button_box_set_layout (GTK_BUTTON_BOX (vbutton_box),
				   GTK_BUTTONBOX_START);
	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(scrw2),
					       vbutton_box);
	gtk_widget_show (vbutton_box);
	cartoon_button_init (cartoon, vbutton_box);
	
	gtk_widget_show (cartoon->app);
	return;
}
